==> connectagram_1.2.10.orig.tar.gz: connectagram-1.2.10/translations/connectagram_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Lanţ</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Încarcă</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>În pauză</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Definiţii</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Descărcare definiţii...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Cuvinte nerezolvate</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>De la Wikționar, dicționarul liber</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Nu s-a găsit nici o definiţie</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Imposibil de conectat la Wikționar</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Îngrădire</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Mică</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medie</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Mare</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Foarte mare</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Limbă:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Mărime cuvînt:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Cantitate de cuvinte:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n literă</numerusform>
            <numerusform>%n litere</numerusform>
            <numerusform>%n litere</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Inele</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Scoruri</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Timp</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Cuvinte</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lungime</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Trepte</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Contorsionat</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Ondulat</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Încarcă</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>În pauză</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definiţii</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Indiciu</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>Alegeţi...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalii</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>Indiciu</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efiniţii</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Scoruri</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Limbă aplicaţie...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Alegeţi joc</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Joc număr:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nu se poate începe jocul solicitat.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Un joc de descîlcire de cuvinte</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Toate drepturile rezervate &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definiţiile sînt de la &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wikționar&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalii</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Model:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Reluare</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.1.orig.tar.gz: connectagram-1.3.1/translations/connectagram_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Lanţ</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Încarcă</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>În pauză</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Îngrădire</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Mică</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medie</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Mare</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Foarte mare</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Limbă:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Mărime cuvînt:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Cantitate de cuvinte:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n literă</numerusform>
            <numerusform>%n litere</numerusform>
            <numerusform>%n litere</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Inele</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Scoruri mari</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rang</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Timp</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Cuvinte</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lungime</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Felicitări!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Ţi-ai bătut cel mai bun scor!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Felicitări!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Ai un nou scor mare!</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Trepte</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Contorsionat</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Ondulat</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Încarcă</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>În pauză</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definiţii</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Indiciu</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>Alegeţi...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalii</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>Indiciu</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efiniţii</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Scoruri mari</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation>Mod Întunecat</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Limbă aplicaţie...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Alegeţi joc</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Joc număr:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nu se poate începe jocul solicitat.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Un joc de descîlcire de cuvinte</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Toate drepturile rezervate &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definiţiile sînt de la &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wikționar&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalii</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Model:</translation>
    </message>
</context>
</TS>
